@@ -6,6 +6,7 @@ import pytest
 from distributed.protocol import loads, dumps, msgpack, maybe_compress, to_serialize
 from distributed.protocol.compression import compressions
 from distributed.protocol.serialize import Serialize, Serialized, serialize, deserialize
+from distributed.system import MEMORY_LIMIT
 from distributed.utils import nbytes
 
 
@@ -57,34 +58,26 @@ def test_small_and_big():
     # assert loads([big_header, big]) == {'y': d['y']}
 
 
-def test_maybe_compress():
-    pass
+@pytest.mark.parametrize(
+    "lib,compression",
+    [(None, None), ("zlib", "zlib"), ("lz4", "lz4"), ("zstandard", "zstd")],
+)
+def test_maybe_compress(lib, compression):
+    if lib:
+        pytest.importorskip(lib)
 
     try_converters = [bytes, memoryview]
-    try_compressions = ["zlib", "lz4"]
 
-    payload = b"123"
-
-    with dask.config.set({"distributed.comm.compression": None}):
+    with dask.config.set({"distributed.comm.compression": compression}):
         for f in try_converters:
+            payload = b"123"
             assert maybe_compress(f(payload)) == (None, payload)
 
-    for compression in try_compressions:
-        try:
-            __import__(compression)
-        except ImportError:
-            continue
-
-        with dask.config.set({"distributed.comm.compression": compression}):
-            for f in try_converters:
-                payload = b"123"
-                assert maybe_compress(f(payload)) == (None, payload)
-
-                payload = b"0" * 10000
-                rc, rd = maybe_compress(f(payload))
-                # For some reason compressing memoryviews can force blosc...
-                assert rc in (compression, "blosc")
-                assert compressions[rc]["decompress"](rd) == payload
+            payload = b"0" * 10000
+            rc, rd = maybe_compress(f(payload))
+            # For some reason compressing memoryviews can force blosc...
+            assert rc in (compression, "blosc")
+            assert compressions[rc]["decompress"](rd) == payload
 
 
 def test_maybe_compress_sample():
@@ -110,13 +103,9 @@ def test_large_bytes():
 @pytest.mark.slow
 def test_large_messages():
     np = pytest.importorskip("numpy")
-    psutil = pytest.importorskip("psutil")
     pytest.importorskip("lz4")
-    if psutil.virtual_memory().total < 8e9:
-        return
-
-    if sys.version_info.major == 2:
-        return 2
+    if MEMORY_LIMIT < 8e9:
+        pytest.skip("insufficient memory")
 
     x = np.random.randint(0, 255, size=200000000, dtype="u1")
 
@@ -134,9 +123,7 @@ def test_large_messages():
 
 
 def test_large_messages_map():
-    import psutil
-
-    if psutil.virtual_memory().total < 8e9:
+    if MEMORY_LIMIT < 8e9:
         pytest.skip("insufficient memory")
 
     x = {i: "mystring_%d" % i for i in range(100000)}
