@@ -415,8 +415,9 @@ def test_restart_timeout_on_long_running_task(c, s, a):
     assert "timeout" not in text.lower()
 
 
-@gen_cluster(client=True, scheduler_kwargs={"worker_ttl": "100ms"})
+@gen_cluster(client=True, scheduler_kwargs={"worker_ttl": "500ms"})
 def test_worker_time_to_live(c, s, a, b):
+    assert set(s.workers) == {a.address, b.address}
     a.periodic_callbacks["heartbeat"].stop()
     yield gen.sleep(0.010)
     assert set(s.workers) == {a.address, b.address}
@@ -424,13 +425,6 @@ def test_worker_time_to_live(c, s, a, b):
     start = time()
     while set(s.workers) == {a.address, b.address}:
         yield gen.sleep(0.050)
-        assert time() < start + 1
+        assert time() < start + 2
 
     set(s.workers) == {b.address}
-
-    start = time()
-    while b.status == "running":
-        yield gen.sleep(0.050)
-        assert time() < start + 1
-
-    assert b.status in ("closed", "closing")
