@@ -217,6 +217,15 @@ def test_remove_worker_from_scheduler(s, a, b):
     s.validate_state()
 
 
+@gen_cluster()
+def test_remove_worker_by_name_from_scheduler(s, a, b):
+    assert a.address in s.stream_comms
+    assert s.remove_worker(address=a.name) == "OK"
+    assert a.address not in s.nthreads
+    assert s.remove_worker(address=a.address) == "already-removed"
+    s.validate_state()
+
+
 @gen_cluster(config={"distributed.scheduler.events-cleanup-delay": "10 ms"})
 def test_clear_events_worker_removal(s, a, b):
     assert a.address in s.events
@@ -408,8 +417,8 @@ def test_delete(c, s, a):
 def test_filtered_communication(s, a, b):
     c = yield connect(s.address)
     f = yield connect(s.address)
-    yield c.write({"op": "register-client", "client": "c"})
-    yield f.write({"op": "register-client", "client": "f"})
+    yield c.write({"op": "register-client", "client": "c", "versions": {}})
+    yield f.write({"op": "register-client", "client": "f", "versions": {}})
     yield c.read()
     yield f.read()
 
@@ -566,7 +575,7 @@ def test_coerce_address():
             "tcp://127.0.0.1:8000",
             "tcp://[::1]:8000",
         )
-        assert s.coerce_address(u"localhost:8000") in (
+        assert s.coerce_address("localhost:8000") in (
             "tcp://127.0.0.1:8000",
             "tcp://[::1]:8000",
         )
@@ -942,10 +951,11 @@ def test_worker_arrives_with_processing_data(c, s, a, b):
     yield w.close()
 
 
+@pytest.mark.slow
 @gen_cluster(client=True, nthreads=[("127.0.0.1", 1)])
 def test_worker_breaks_and_returns(c, s, a):
     future = c.submit(slowinc, 1, delay=0.1)
-    for i in range(10):
+    for i in range(20):
         future = c.submit(slowinc, future, delay=0.1)
 
     yield wait(future)
@@ -957,10 +967,10 @@ def test_worker_breaks_and_returns(c, s, a):
     yield wait(future, timeout=10)
     end = time()
 
-    assert end - start < 1
+    assert end - start < 2
 
     states = frequencies(ts.state for ts in s.tasks.values())
-    assert states == {"memory": 1, "released": 10}
+    assert states == {"memory": 1, "released": 20}
 
 
 @gen_cluster(client=True, nthreads=[])
@@ -1211,14 +1221,15 @@ def test_profile_metadata(c, s, a, b):
 
 @gen_cluster(client=True, worker_kwargs={"profile_cycle_interval": 100})
 def test_profile_metadata_keys(c, s, a, b):
-    start = time() - 1
     x = c.map(slowinc, range(10), delay=0.05)
     y = c.map(slowdec, range(10), delay=0.05)
     yield wait(x + y)
 
     meta = yield s.get_profile_metadata(profile_cycle_interval=0.100)
     assert set(meta["keys"]) == {"slowinc", "slowdec"}
-    assert len(meta["counts"]) == len(meta["keys"]["slowinc"])
+    assert (
+        len(meta["counts"]) - 3 <= len(meta["keys"]["slowinc"]) <= len(meta["counts"])
+    )
 
 
 @gen_cluster(client=True)
@@ -1501,21 +1512,32 @@ def test_gh2187(c, s, a, b):
     yield f
 
 
-@gen_cluster(client=True, config={"distributed.scheduler.idle-timeout": "200ms"})
-def test_idle_timeout(c, s, a, b):
+@gen_cluster(client=True)
+def test_collect_versions(c, s, a, b):
+    cs = s.clients[c.id]
+    (w1, w2) = s.workers.values()
+    assert cs.versions
+    assert w1.versions
+    assert w2.versions
+    assert "dask" in str(cs.versions)
+    assert cs.versions == w1.versions == w2.versions
+
+
+@gen_cluster(client=True, config={"distributed.scheduler.idle-timeout": "500ms"})
+async def test_idle_timeout(c, s, a, b):
     future = c.submit(slowinc, 1)
-    yield future
+    await future
 
     assert s.status != "closed"
 
     start = time()
     while s.status != "closed":
-        yield gen.sleep(0.01)
-    assert time() < start + 3
+        await gen.sleep(0.01)
+        assert time() < start + 3
 
     start = time()
     while not (a.status == "closed" and b.status == "closed"):
-        yield gen.sleep(0.01)
+        await gen.sleep(0.01)
         assert time() < start + 1
 
 
@@ -1851,7 +1873,7 @@ async def test_gather_allow_worker_reconnect(c, s, a, b):
         # need to sleep for at least 0.5 seconds to give the worker a chance to
         # reconnect (Heartbeat timing)
         if x in ALREADY_CALCULATED:
-            time.sleep(0.5)
+            time.sleep(1)
         ALREADY_CALCULATED.append(x)
         return x + 1
 
@@ -1953,3 +1975,16 @@ async def test_multiple_listeners(cleanup):
     log = log.getvalue()
     assert re.search(r"Scheduler at:\s*tcp://", log)
     assert re.search(r"Scheduler at:\s*inproc://", log)
+
+
+@gen_cluster(nthreads=[("127.0.0.1", 1)])
+async def test_worker_name_collision(s, a):
+    # test that a name collision for workers produces the expected respsone
+    # and leaves the data structures of Scheduler in a good state
+    # is not updated by the second worker
+    with pytest.raises(ValueError, match=f"name taken, {a.name!r}"):
+        await Worker(s.address, name=a.name, loop=s.loop, host="127.0.0.1")
+
+    s.validate_state()
+    assert set(s.workers) == {a.address}
+    assert s.aliases == {a.name: a.address}
